@@ -11,7 +11,7 @@ class Translator(TranslatorBase):
     def translate_function(self, cls, method, model):
         if not method.translated:
             body = '\n'.join(method.operations)
-            body = self.translate_function_body(cls, body, model)
+            body = self.translate_function_body(cls, method, body, model, method.args)
             method.body = body
         else:
             if method.operations:
@@ -19,36 +19,42 @@ class Translator(TranslatorBase):
             else:
                 method.body = 'pass'
 
-    def translate_function_body(self, class_, func, model):
-        if not func:
-            func = 'pass'
-        func = self.replace_by_regex(func)
-        func = Translator.convert_braces_to_tabs(func)
-        func = Translator.remove_double_eol(func)
-        func = Translator.add_imports(class_, func, model)
-        return func
+    def translate_function_body(self, cls, method, body, model, args):
+        if not body:
+            body = 'pass'
+        body = self.replace_by_regex(method, body, model, args)
+        body = Translator.convert_braces_to_tabs(body)
+        body = Translator.remove_double_eol(body)
+        body = Translator.add_imports(cls, body, model)
+        return body
 
     @staticmethod
     def add_imports(cls_owner, func, model):
         if not func:
             return func
-        if 'DataStorage' in func:
-            func = Translator.get_tabs(2) + 'from .DataStorage import DataStorage\n' + func
+        imports = []
         if RegexPatternPython.FACTORY.search(func):
-            func = Translator.get_tabs(2) + 'from .Factory import Factory\n' + func
+            imports.append('from .Factory import Factory')
         for cls in model.classes:
             if cls.name in func:
+                need = cls.name is not cls_owner.name
+                if not need:
+                    continue
+                pattern = None
                 if cls.name not in RegexPatternPython.regs_class_names:
-                    RegexPatternPython.regs_class_names[cls.name] = re.compile(r'\b{}\b'.format(cls.name))
-                pattern = RegexPatternPython.regs_class_names[cls.name]
-                need = cls.name != cls_owner.name
+                    pattern = re.compile(r'\b{}\b'.format(cls.name))
+                    RegexPatternPython.regs_class_names[cls.name] = pattern
+                pattern = pattern or RegexPatternPython.regs_class_names[cls.name]
                 need = need and pattern.search(func) is not None
                 if need:
-                    func = Translator.get_tabs(2) + 'from .{0} import {0}\n'.format(cls.name) + func
+                    imports.append('from .{0} import {0}'.format(cls.name))
         if 'math.' in func:
-            func = Translator.get_tabs(2) + 'import math\n' + func
+            imports.append('import math')
         if 'random.' in func:
-            func = Translator.get_tabs(2) + 'import random\n' + func
+            imports.append('import random')
+        if imports:
+            imports = Translator.get_tabs(2) + '\n{}'.format(Translator.get_tabs(2)).join(imports)
+            func = '{}\n{}'.format(imports, func)
         return func
 
     @staticmethod
@@ -91,14 +97,14 @@ class Translator(TranslatorBase):
         func = '\n'.join(lines)
         return func
 
-    def replace_by_regex(self, func):
-        if not func:
-            return func
+    def replace_by_regex(self, func, body, model, args):
+        if not body:
+            return body
         for reg in RegexPatternPython.FUNCTION:
-            func = self.replace(func, reg)
+            body = self.replace(body, reg)
         for reg in RegexPatternPython.REPLACES:
-            func = func.replace(reg[0], reg[1])
-        return func
+            body = body.replace(reg[0], reg[1])
+        return body
 
     @staticmethod
     def get_tabs(count):
